
library(rFIA)
library(tidyverse)


getFIA(load = FALSE, dir = "FIA_data/",
       states=c("TX", "OK", "KS", "NE", "SD", "ND", "LA", "AR", "MO", "IA", "MN",
                "FL", "MS", "AL", "GA", "TN", "KY", "IL", "IN", "OH", "WI", "MI",
                "SC", "NC", "VA", "WV", "PA", "MD", "NJ", "NY", "CT", "MA", "VT", "NH", "ME", "RI", "DE"))

fia <- readFIA("FIA_data/", inMemory = FALSE)

fia.statesub <- readFIA("FIA_data/", inMemory = FALSE, states = c("MN", "IL", "IN", "OH", "WI", "MI",
                                                                  "PA", "MD", "NJ", "NY", "CT", "MA", "VT", "NH", "ME", "RI", "DE"))

fiaMR <- clipFIA(fia, mostRecent = TRUE)

fiaMR.statesub <- clipFIA(fia.statesub, mostRecent = TRUE)

# FIA tables
FIA_plot_table <- readFIA(dir = 'FIA_data/', tables = 'PLOT', inMemory = TRUE)
FIA_cond_table <- readFIA(dir = 'FIA_data/', tables = 'COND', inMemory = TRUE)
FIA_tree_table <- readFIA(dir = 'FIA_data/', tables = 'TREE', inMemory = TRUE)

# Combine PLOT, COND, and TREE tables
FIA_tbl_all <- FIA_plot_table$PLOT %>%
  # Rename the CN column in plot, PLT_CN for simple joining
  mutate(PLT_CN = CN) %>%
  # Join tables
  left_join(FIA_cond_table$COND, by = 'PLT_CN') %>%
  left_join(FIA_tree_table$TREE, by = c('PLT_CN', 'CONDID'))


# Subset FIA table by species code 
FIA_tbl_ASAC <- subset(FIA_tbl_all, FIA_tbl_all$SPCD == 318)
FIA_tbl_ASRI <- subset(FIA_tbl_all, FIA_tbl_all$SPCD == 317)
FIA_tbl_PTRM <- subset(FIA_tbl_all, FIA_tbl_all$SPCD == 746)
FIA_tbl_PDEL <- subset(FIA_tbl_all, FIA_tbl_all$SPCD == 742)


FIA_tbl_ASAC.PTRM <- rbind.data.frame(FIA_tbl_ASAC, FIA_tbl_PTRM)
FIA_tbl_ASRI.PDEL <- rbind.data.frame(FIA_tbl_ASRI, FIA_tbl_PDEL)


# Find plots with both Acer & Populus species pairs
ASAC.PTRM_FIA_join <- inner_join(FIA_tbl_ASAC, FIA_tbl_PTRM, by="PLT_CN")
ASRI.PDEL_FIA_join <- inner_join(FIA_tbl_ASRI, FIA_tbl_PDEL, by="PLT_CN")

# Estimate total trees and basal area per acre (TPA and BAA)
fiaMR_tpa_species <- tpa(fia, bySpecies = TRUE, byPlot = T)
fiaMR2_tpa_species <- tpa(fiaMR, bySpecies = TRUE, byPlot = T)

fiaMR3_tpa_species <- tpa(fiaMR.statesub, bySpecies = TRUE, byPlot = T)

# Sum total BAA per plot
FIA_plot_totalBAA <- fiaMR2_tpa_species %>%
  group_by(PLT_CN) %>%
  summarise(TotalBAA = sum(BAA))



# Subset the four tree species
ASAC.fia.sub <- subset(fiaMR2_tpa_species, fiaMR2_tpa_species$SCIENTIFIC_NAME=="Acer saccharum")
ASRI.fia.sub <- subset(fiaMR_tpa_species, fiaMR_tpa_species$SCIENTIFIC_NAME=="Acer saccharinum")
PTRM.fia.sub <- subset(fiaMR2_tpa_species, fiaMR2_tpa_species$SCIENTIFIC_NAME=="Populus tremuloides")
PDEL.fia.sub <- subset(fiaMR_tpa_species, fiaMR_tpa_species$SCIENTIFIC_NAME=="Populus deltoides")

ASAC.fia.sub.filt <- subset(ASAC.fia.sub, ASAC.fia.sub$PROP_FOREST==1)
ASRI.fia.sub.filt <- subset(ASRI.fia.sub, ASRI.fia.sub$PROP_FOREST==1)
PTRM.fia.sub.filt <- subset(PTRM.fia.sub, PTRM.fia.sub$PROP_FOREST==1)
PDEL.fia.sub.filt <- subset(PDEL.fia.sub, PDEL.fia.sub$PROP_FOREST==1)

# Join ACER and POPULUS records
ASAC.PTRM <- full_join(ASAC.fia.sub.filt, PTRM.fia.sub.filt, by='PLT_CN')
ASRI.PDEL <- full_join(ASRI.fia.sub.filt, PDEL.fia.sub.filt, by='PLT_CN')


ASAC.PTRM.totalBAA <- inner_join(ASAC.PTRM, FIA_plot_totalBAA, by = "PLT_CN")
ASRI.PDEL.totalBAA <- inner_join(ASRI.PDEL, FIA_plot_totalBAA, by = "PLT_CN")

ASAC.BAA <- ASAC.PTRM.totalBAA$BAA.x/ASAC.PTRM.totalBAA$TotalBAA
ASAC.PTRM.totalBAA <- cbind.data.frame(ASAC.PTRM.totalBAA, ASAC.BAA = ASAC.BAA)

ASRI.BAA <- ASRI.PDEL.totalBAA$BAA.x/ASRI.PDEL.totalBAA$TotalBAA
ASRI.PDEL.totalBAA <- cbind.data.frame(ASRI.PDEL.totalBAA, ASRI.BAA = ASRI.BAA)

PTRM.BAA <- ASAC.PTRM.totalBAA$BAA.y/ASAC.PTRM.totalBAA$TotalBAA
ASAC.PTRM.totalBAA <- cbind.data.frame(ASAC.PTRM.totalBAA, PTRM.BAA = PTRM.BAA)

PDEL.BAA <- ASRI.PDEL.totalBAA$BAA.y/ASRI.PDEL.totalBAA$TotalBAA
ASRI.PDEL.totalBAA <- cbind.data.frame(ASRI.PDEL.totalBAA, PDEL.BAA = PDEL.BAA)

#ASAC.PTRM.totalBAA.sub <- subset(ASAC.PTRM.totalBAA, ASAC.BAA >= 0.5 | PTRM.BAA >= 0.5)
#ASRI.PDEL.totalBAA.sub <- subset(ASRI.PDEL.totalBAA, ASRI.BAA >= 0.5 | PDEL.BAA >= 0.5)

#length(unique(ASAC.PTRM.totalBAA.sub$PLT_CN)) # 2659 forest plots where ASAC or PTRM accounts for at least 50% of total BAA
#length(unique(ASRI.PDEL.totalBAA.sub$PLT_CN)) # 219 forest plots where ASRI or PDEL accounts for at least 50% of total BAA

#length(unique(ASAC.PTRM$PLT_CN)) #1457 100% Forested plots with both PTRM and ASAC (out of 10824 total); ~13.5% coexistence
#length(unique(ASRI.PDEL$PLT_CN)) #284 100% Forested plots with both PDEL & ASRI (out of 2011); ~14%

Prop.PTRM <- ASAC.PTRM.totalBAA$BAA.y/(ASAC.PTRM.totalBAA$BAA.x + ASAC.PTRM.totalBAA$BAA.y)
Prop.PDEL <- ASRI.PDEL.totalBAA$BAA.y/(ASRI.PDEL.totalBAA$BAA.x + ASRI.PDEL.totalBAA$BAA.y)

#ASAC.PTRM.ratio <- log(ASAC.PTRM$BAA.x/ASAC.PTRM$BAA.y)
#ASRI.PDEL.ratio <- log(ASRI.PDEL$BAA.x/ASRI.PDEL$BAA.y)

ASAC.PTRM.BAA.propEM.join <- cbind.data.frame(ASAC.PTRM.totalBAA, Prop.PTRM = Prop.PTRM)
ASRI.PDEL.BAA.propEM.join <- cbind.data.frame(ASRI.PDEL.totalBAA, Prop.PDEL = Prop.PDEL)

#ASAC.PTRM.BAA.propEM.join$Prop.PTRM[is.na(ASAC.PTRM.BAA.propEM.join$Prop.PTRM)] <- 0

ASAC.PTRM.BAA.propEM.join$BAA.x[is.na(ASAC.PTRM.BAA.propEM.join$BAA.x)] <- 0
ASAC.PTRM.BAA.propEM.join$BAA.y[is.na(ASAC.PTRM.BAA.propEM.join$BAA.y)] <- 0

ASRI.PDEL.BAA.propEM.join$BAA.x[is.na(ASRI.PDEL.BAA.propEM.join$BAA.x)] <- 0
ASRI.PDEL.BAA.propEM.join$BAA.y[is.na(ASRI.PDEL.BAA.propEM.join$BAA.y)] <- 0


###
# Organize data to show bimodal histogram
###

###  NORTHERN
ASAC.PTRM.BAA.propEM.join.new <- ASAC.PTRM.BAA.propEM.join %>% mutate(ASAC.forest = 
                                                                        ifelse(BAA.y==0 & ASAC.BAA >= 0.90, -1, 0),
                                                                      PTRM.forest = 
                                                                        ifelse(BAA.x==0 & PTRM.BAA >= 0.90, 1, 0))

PTRM.forest.sub <- subset(ASAC.PTRM.BAA.propEM.join.new, PTRM.forest==1)
names(PTRM.forest.sub)[names(PTRM.forest.sub) == 'PTRM.forest'] <- 'Prop.EM.forest'

ASAC.forest.sub <- subset(ASAC.PTRM.BAA.propEM.join.new, ASAC.forest==-1)
names(ASAC.forest.sub)[names(ASAC.forest.sub) == 'ASAC.forest'] <- 'Prop.EM.forest'
ASAC.forest.sub[ASAC.forest.sub == -1] <- 0

names(ASAC.PTRM.BAA.propEM.join.new)[names(ASAC.PTRM.BAA.propEM.join.new) == 'Prop.PTRM'] <- 'Prop.EM.forest'

ASAC.PTRM.Prop.EM.forest <- bind_rows(ASAC.PTRM.BAA.propEM.join.new, 
                                             PTRM.forest.sub, 
                                             ASAC.forest.sub)

hist(ASAC.PTRM.Prop.EM.forest$Prop.EM.forest, breaks=20)

ASAC.PTRM.Prop.EM.forest.narm <- subset(ASAC.PTRM.Prop.EM.forest, Prop.EM.forest != "NA")
length(unique(ASAC.PTRM.Prop.EM.forest.narm$PLT_CN))
#1841


###  SOUTHERN

ASRI.PDEL.BAA.propEM.join.new <- ASRI.PDEL.BAA.propEM.join %>% mutate(ASRI.forest = 
                                                                        ifelse(BAA.y==0 & ASRI.BAA >= 0.90, -1, 0),
                                                                      PDEL.forest = 
                                                                        ifelse(BAA.x==0 & PDEL.BAA >= 0.90, 1, 0))

PDEL.forest.sub <- subset(ASRI.PDEL.BAA.propEM.join.new, PDEL.forest == 1)
names(PDEL.forest.sub)[names(PDEL.forest.sub) == 'PDEL.forest'] <- 'Prop.EM.forest'

ASRI.forest.sub <- subset(ASRI.PDEL.BAA.propEM.join.new, ASRI.forest == -1)
names(ASRI.forest.sub)[names(ASRI.forest.sub) == 'ASRI.forest'] <- 'Prop.EM.forest'
ASRI.forest.sub[ASRI.forest.sub == -1] <- 0

names(ASRI.PDEL.BAA.propEM.join.new)[names(ASRI.PDEL.BAA.propEM.join.new) == 'Prop.PDEL'] <- 'Prop.EM.forest'

ASRI.PDEL.Prop.EM.forest <- bind_rows(ASRI.PDEL.BAA.propEM.join.new, 
                                      PDEL.forest.sub, 
                                      ASRI.forest.sub)

hist(ASRI.PDEL.Prop.EM.forest$Prop.EM.forest, breaks=20)

ASRI.PDEL.Prop.EM.forest.narm <- subset(ASRI.PDEL.Prop.EM.forest, Prop.EM.forest != "NA")
length(unique(ASRI.PDEL.Prop.EM.forest.narm$PLT_CN))
# 126



### Plotting histograms
library(RColorBrewer)

PTRM.palette <- colorRampPalette(colors = c("#FDF4EE", "#EE6100"))(15)
ASAC.palette <- colorRampPalette(colors = c("#0477BB", "#EEF5FA"))(15)
ASAC.PTRM.palette <- c(ASAC.palette, PTRM.palette)
#scales::show_col(ASAC.palette)

PDEL.palette <- colorRampPalette(colors = c("#FFF9EE", "#FFAE08"))(15)
ASRI.palette <- colorRampPalette(colors = c("#19B5AF", "#EFFAF9"))(15)
ASRI.PDEL.palette <- c(ASRI.palette, PDEL.palette)
scales::show_col(ASRI.PDEL.palette)


pdf(file="ASAC.PTRM.forestbarchart.pdf", width=3, height=2)
ggplot() +
  geom_histogram(data=ASAC.PTRM.Prop.EM.forest, aes(x=Prop.EM.forest), fill=ASAC.PTRM.palette, bins=30, na.rm=T) +
  xlab("Proportion of PTRM trees") +
  ylab("Number of forests") +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 280)) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()

pdf(file="ASRI.PDEL.forestbarchart.pdf", width=3, height=2)
ggplot() +
  geom_histogram(data=ASRI.PDEL.Prop.EM.forest, aes(x=Prop.EM.forest), fill=ASRI.PDEL.palette, bins=30, na.rm=T) +
  xlab("Proportion of PDEL trees") +
  ylab("Number of forests") +
  scale_y_continuous(expand = c(0, 0), limits = c(0, 30)) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()




















plot(BAA.y ~ Prop.EM.forest, data=ASAC.PTRM.Prop.EM.forest)
plot(BAA.x ~ Prop.EM.forest, data=ASRI.PDEL.Prop.EM.forest)

#summary(lm(BAA.x ~ Prop.PTRM, data=ASAC.PTRM.propEM.join))
#summary(lm(BAA.x ~ Prop.PDEL, data=subset(ASRI.PDEL.propEM.join, BAA.y<200)))

pdf(file="ASAC.PTRM.FIA_Bimodality.figure.pdf", width=2.5, height=2)
ggplot() +
  #geom_vline(xintercept = 0.5, color="black", linetype="dashed") +
  geom_point(data=ASAC.PTRM.BAA.propEM.join, aes(x=Prop.PTRM, y=BAA.x), shape=1, size=0.75, alpha=0.3, color="#0477BB", na.rm=T) +
  geom_point(data=ASAC.PTRM.BAA.propEM.join, aes(x=Prop.PTRM, y=BAA.y), shape=1, size=0.75, alpha=0.3, color="#EE6100", na.rm=T) +
  geom_smooth(data=ASAC.PTRM.BAA.propEM.join, aes(x=Prop.PTRM, y=BAA.x), method="loess", color="#0477BB", lwd=1, se=F) +
  geom_smooth(data=ASAC.PTRM.BAA.propEM.join, aes(x=Prop.PTRM, y=BAA.y), method="loess", color="#EE6100", lwd=1, se=F) +
  xlab("Relative dominance of Poplar (EM) trees") +
  ylab("Tree basal area (ft/acre)") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()



pdf(file="ASRI.PDEL.FIA_Bimodality.figure.pdf", width=3, height=2.75)
ggplot() +
  #geom_vline(xintercept = 0.5, color="black", linetype="dashed") +
  geom_point(data=ASRI.PDEL.BAA.propEM.join, aes(x=Prop.PDEL, y=BAA.x), shape=1, size=0.75, alpha=0.3, color="#0477BB", na.rm=T) +
  geom_point(data=ASRI.PDEL.BAA.propEM.join, aes(x=Prop.PDEL, y=BAA.y), shape=1, size=0.75, alpha=0.3, color="#EE6100", na.rm=T) +
  geom_smooth(data=ASRI.PDEL.BAA.propEM.join, aes(x=Prop.PDEL, y=BAA.x), method="loess", color="#0477BB", lwd=1, se=F) +
  geom_smooth(data=ASRI.PDEL.BAA.propEM.join, aes(x=Prop.PDEL, y=BAA.y), method="loess", color="#EE6100", lwd=1, se=F) +
  xlab("Relative dominance of Poplar (EM) trees") +
  ylab("Tree basal area (ft/acre)") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()








# Create ratio of Acer:Populus BAA 
ASAC_FIA_TPA <- left_join(ASAC.PTRM_FIA_join, ASAC.fia.sub, by="PLT_CN")
PTRM_FIA_TPA <- left_join(ASAC.PTRM_FIA_join, PTRM.fia.sub, by="PLT_CN")
ASAC.PTRM.baa <- log(ASAC_FIA_TPA$BAA/PTRM_FIA_TPA$BAA)
ASAC.PTRM_FIA_join_BAA <- cbind.data.frame(ASAC.PTRM_FIA_join, ASAC.PTRM.BAA.ratio = ASAC.PTRM.baa)

ASRI_FIA_TPA <- left_join(ASRI.PDEL_FIA_join, ASRI.fia.sub, by="PLT_CN")
PDEL_FIA_TPA <- left_join(ASRI.PDEL_FIA_join, PDEL.fia.sub, by="PLT_CN")
ASRI.PDEL.baa <- log(ASRI_FIA_TPA$BAA/PDEL_FIA_TPA$BAA)
ASRI.PDEL_FIA_join_BAA <- cbind.data.frame(ASRI.PDEL_FIA_join, ASRI.PDEL.BAA.ratio = ASRI.PDEL.baa)




# Estimate total trees and basal area per acre (TPA and BAA)
fia_tpa_species <- tpa(fia, bySpecies = TRUE, byPlot = T)

# Subset the four tree species
ASAC.fia.sub2 <- subset(fia_tpa_species, fia_tpa_species$SCIENTIFIC_NAME=="Acer saccharum")
ASRI.fia.sub2 <- subset(fia_tpa_species, fia_tpa_species$SCIENTIFIC_NAME=="Acer saccharinum")
PTRM.fia.sub2 <- subset(fia_tpa_species, fia_tpa_species$SCIENTIFIC_NAME=="Populus tremuloides")
PDEL.fia.sub2 <- subset(fia_tpa_species, fia_tpa_species$SCIENTIFIC_NAME=="Populus deltoides")


# Combine data by updated plotID
ASAC.PTRM.2 <- left_join(ASAC.fia.sub2, PTRM.fia.sub2, by='pltID')
ASRI.PDEL.2 <- left_join(ASRI.fia.sub2, PDEL.fia.sub2, by='pltID')

mod1 <- lm(BAA.y ~ BAA.x, data = ASAC.PTRM.2)
summary(lm(BAA.y ~ BAA.x, data = ASAC.PTRM.2)) #r2=0.02, p<0.001
plot(BAA.y ~ BAA.x, data = ASAC.PTRM.2)
abline(mod1, col="red")

mod2 <- lm(BAA.y ~ BAA.x, data=subset(ASRI.PDEL.2, ASRI.PDEL.2$BAA.y<175)) # remove some outliers >175 BAA
summary(lm(BAA.y ~ BAA.x, data=subset(ASRI.PDEL.2, ASRI.PDEL.2$BAA.y<175))) # r2=0.01, p<0.001
plot(BAA.y ~ BAA.x, data=subset(ASRI.PDEL.2, ASRI.PDEL.2$BAA.y<175))
abline(mod2, col="red")


pdf(file="FIA_BAA_corr.figure.pdf", width=3, height=3)
ggplot() +
  geom_point(data=ASAC.PTRM.2, aes(x=BAA.x, y=BAA.y), color="black", shape=".", alpha=0.25) +
  geom_point(data=subset(ASRI.PDEL.2, ASRI.PDEL.2$BAA.y<175), aes(x=BAA.x, y=BAA.y), color="darkgrey", shape=".", alpha=0.75) +
  geom_smooth(data=ASAC.PTRM.2, aes(x=BAA.x, y=BAA.y), method="lm", color="black", lwd=1, se=F) +
  geom_smooth(data=subset(ASRI.PDEL.2, ASRI.PDEL.2$BAA.y<175), aes(x=BAA.x, y=BAA.y), method="lm", color="darkgrey", lwd=1, se=F) +
  xlab("Acer basal area (ft/acre)") +
  ylab("Populus basal area (ft/acre)") +
  xlim(0,175) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()



###                                     ###
###  Mapping tree species coordinates   ###
###                                     ###

USA_map <- ne_countries(country = "United States of America")
plot(USA_map)

b <- as(extent(-124.7, -55.66667, 24.5, 49.4), "SpatialPolygons")
crs(b) <- crs(USA_map)
USA_map_cropped <- raster::crop(USA_map, b)


FIA_tbl_ASAC.PTRM.pltgrp <- FIA_tbl_ASAC.PTRM %>% group_by(PLT_CN)
FIA_tbl_ASAC.PTRM.ratio <- inner_join(ASAC.PTRM.Prop.EM.forest.narm, FIA_tbl_ASAC.PTRM.pltgrp, by = "PLT_CN")

FIA_tbl_ASRI.PDEL.pltgrp <- FIA_tbl_ASRI.PDEL %>% group_by(PLT_CN)
FIA_tbl_ASRI.PDEL.ratio <- inner_join(ASRI.PDEL.Prop.EM.forest.narm, FIA_tbl_ASRI.PDEL.pltgrp, by = "PLT_CN")


pdf(file="ASAC.PTRM_fia.map.pdf", width=8, height=8)
ggplot() +
  geom_sf(data = st_as_sf(USA_map_cropped), fill = "black", col = "black", lwd=0.2) +
  geom_point(data = FIA_tbl_ASAC.PTRM.ratio, aes(x=LON, y=LAT, color=Prop.EM.forest), size=0.5) +
  scale_colour_gradient2(low="#0477BB", mid="white", high="#EE6100", midpoint = 0.5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()


pdf(file="ASRI.PDEL_fia.map.pdf", width=8, height=8)
ggplot() +
  geom_sf(data = st_as_sf(USA_map_cropped), fill = "black", col = "black", lwd=0.2) +
  geom_point(data = FIA_tbl_ASRI.PDEL.ratio, aes(x=LON, y=LAT, color=Prop.EM.forest), size=0.7) +
  scale_color_gradient2(low="#19B5AF", mid="white", high="#FFAE08", midpoint = 0.5) +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(), panel.background = element_blank())
dev.off()






pdf(file="Full_fia.map.pdf", width=14, height=14)
ggplot() +
  geom_sf(data = st_as_sf(USA_map_cropped), fill = "black", col = "black", lwd=0.2) +
  geom_point(data = FIA_tbl_PTRM, aes(x=LON, y=LAT), shape=".", size=4, color="#EE6100") +
  geom_point(data = FIA_tbl_ASAC, aes(x=LON, y=LAT), shape=".", size=4, color="#0477BB") +
  geom_point(data = FIA_tbl_PDEL, aes(x=LON, y=LAT), shape=".", size=4, color="#FFAE08") +
  geom_point(data = FIA_tbl_ASRI, aes(x=LON, y=LAT), shape=".", size=4, color="#19B5AF") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()


###############

# Joined plot maps:

ASAC.PTRM_FIA_join_BAA.narm <- subset(ASAC.PTRM_FIA_join_BAA, ASAC.PTRM.BAA.ratio != "NA")
ASRI.PDEL_FIA_join_BAA.narm <- subset(ASRI.PDEL_FIA_join_BAA, ASRI.PDEL.BAA.ratio != "NA")


ASAC.PTRM_FIA_join_BAA.narm.sub <- cbind.data.frame(Longitude = ASAC.PTRM_FIA_join_BAA.narm$LON.x,
                                                    Latitude = ASAC.PTRM_FIA_join_BAA.narm$LAT.x,
                                                    ASAC.PTRM.BAA.ratio = ASAC.PTRM_FIA_join_BAA.narm$ASAC.PTRM.BAA.ratio)

ASRI.PDEL_FIA_join_BAA.narm.sub <- cbind.data.frame(Longitude = ASRI.PDEL_FIA_join_BAA.narm$LON.x,
                                                    Latitude = ASRI.PDEL_FIA_join_BAA.narm$LAT.x,
                                                    ASRI.PDEL.BAA.ratio = ASRI.PDEL_FIA_join_BAA.narm$ASRI.PDEL.BAA.ratio)

write.csv(ASAC.PTRM_FIA_join_BAA.narm.sub, file='ASAC.PTRM_FIA_join_BAA.narm.sub.csv')
write.csv(ASRI.PDEL_FIA_join_BAA.narm.sub, file='ASRI.PDEL_FIA_join_BAA.narm.sub.csv')


pdf(file="Joined_fia.map.pdf", width=14, height=14)
ggplot() +
  geom_sf(data = st_as_sf(USA_map_cropped), fill = "white", col = "black", lwd=0.2) +
  geom_point(data=ASAC.PTRM_FIA_join_BAA.narm, aes(x=LON.x, y=LAT.x), shape=16, size=0.75, color="black") +
  geom_point(data=ASRI.PDEL_FIA_join_BAA.narm, aes(x=LON.x, y=LAT.x), shape=16, size=0.75, color="grey30") +
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
dev.off()

